@@ -50,15 +50,15 @@ authorize <- function(app_name = NULL,
       collapse = ", ")))
     message("Do you want to overwrite these with new credentials?")
     use_old <- menu(c("Yes, overwrite the credentials",
-    "No, I'll use these credentials and stop this function."))
+    "No, I'll use these credentials and stop this function.")) 
+    if (use_old == 1) delete_creds(app_name)
     if (use_old == 2) stop("Using old credentials")
   }
 
   if (!cache) {
     message("Would you like to store/cache your credentials?")
     cache_it <- menu(c("Yes cache/store credentials",
-    "No do not store credentials, I will re-run this authorize()",
-     " in my next R session"))
+    "No do not store credentials, I will re-run this authorize() in my next R session"))
     if (cache_it == 1) {
       message("You chose to cache your credentials,",
       " if you change your mind, run metricminer::delete_creds(). \n",
