@@ -4,38 +4,32 @@
 #' Get Slido Files
 #' @description This is a function to get slido response output files.
 #' The slido files must be saved as googlesheets and cannot be xlsx.
-#' The scope it uses is the `See, edit, create, and delete all your Google Sheets spreadsheets.`
-#' If you don't check this box on the OAuth screen this function won't work.
-#' @param drive_id a URL or drive id that has the slido response output files you are looking to get (will recursively search for files by default).
-#' @param token credentials for access to Google using OAuth. `authorize("google")`
-#' @param recursive Should slido files be looked for recursively in this folder? default is TRUE.
+#' Authentication for this function is handled by the `googledrive` package.
+#' However, the user will need to authorize their google account twice (once for googledrive and once for googlesheets).
+#' If you don't check these boxes on the OAuth screens, this function won't work.
+#' @param shared_drive_name a name of a shared drive (not a URL or subpart of a URL) (will recursively search for files by default).
+#' @param tags_to_find pattern or character that's a regular expression to look for in file names. Default is "^Polls-per|^JoinedParticipants-" which will search for files starting with either of those patterns.
+#' @param file_type which file type to search for. Default is "spreadsheet"
 #' @param keep_duplicates By default we won't keep duplicated files if a two files have the same name. But if you set this to true, duplicates will be returned.
 #' @return A list of the slido files and their content in a Googledrive location.
 #' @import dplyr
-#' @importFrom googledrive as_id drive_ls
+#' @importFrom googledrive as_id drive_find drive_auth
 #' @importFrom googlesheets4 read_sheet
 #' @export
 #'
 #' @examples \dontrun{
 #'
-#' drive_id <- "https://drive.google.com/drive/folders/0AJb5Zemj0AAkUk9PVA"
-#' drive_id <- "https://drive.google.com/drive/u/0/folders/1XWXHHyj32Uw_UyaUJrqp6S--hHnM0-7l"
-#' slido_data <- get_slido_files(drive_id)
+#' shared_drive_name <- "ITCR"
+#' slido_data <- get_slido_files(shared_drive_name)
 #' }
-get_slido_files <- function(drive_id, token = NULL, recursive = TRUE, keep_duplicates = FALSE) {
-  if (is.null(token)) {
-    # Get auth token
-    token <- get_token(app_name = "google")
-  }
+get_slido_files <- function(shared_drive_name, tags_to_find = "^Polls-per|^JoinedParticipants-", file_type = "spreadsheet", keep_duplicates = FALSE) {
 
-  spreadsheet_list <- googledrive::drive_ls(
-    googledrive::as_id(drive_id),
-    type = "spreadsheet",
-    recursive = recursive
-  )
+  googledrive::drive_auth()
 
-  if (length(spreadsheet_list) == 0) {
-    stop("No spreadsheets found in this drive Id provided")
+  spreadsheet_list <- drive_find(tags_to_find, type=file_type, shared_drive = shared_drive_name)
+
+  if (nrow(spreadsheet_list) == 0) {
+    stop("No slido associated spreadsheets found in the shared drive for the name provided")
   }
 
   file_info <- data.frame(
